==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/modules/react-components/stories/components/button/button.stories.meta.ts <==
/*
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { StoryCategories } from "../../hierarchy";
import { StoryMetaInterface } from "../../models";

export const meta: StoryMetaInterface = {
    components: [ "Button", "PrimaryButton", "SecondaryButton", "DangerButton", "LinkButton" ],
    description: "Button component.",
    stories: [
        {
            description: "Default button",
            title: "Default Button",
        },
        {
            description: "Button with product primary color.",
            title: "Primary Button"
        },
        {
            description: "Button with product secondary color.",
            title: "Secondary Button"
        },
        {
            description: "Button that appears as a link",
            title: "Link Button"
        },
        {
            description: "Button to exhibit danger actions.",
            title: "Danger Button"
        },
        {
            description: "Button with a custom icon.",
            title: "Icon Button"
        }
    ],
    title: StoryCategories.COMPONENTS + "/Button",
};

==> identity-apps-1.2.150-source-release.zip: identity-apps-1.2.150/modules/react-components/stories/components/button/button.stories.meta.ts <==
/*
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { StoryCategories } from "../../hierarchy";
import { StoryMetaInterface } from "../../models";

export const meta: StoryMetaInterface = {
    components: [ "Button", "PrimaryButton", "SecondaryButton", "DangerButton", "LinkButton" ],
    description: "Button component.",
    stories: [
        {
            description: "Default button",
            title: "Default Button"
        },
        {
            description: "Button with product primary color.",
            title: "Primary Button"
        },
        {
            description: "Button with product secondary color.",
            title: "Secondary Button"
        },
        {
            description: "Button that appears as a link",
            title: "Link Button"
        },
        {
            description: "Button to exhibit danger actions.",
            title: "Danger Button"
        },
        {
            description: "Button with a custom icon.",
            title: "Icon Button"
        }
    ],
    title: StoryCategories.COMPONENTS + "/Button"
};
